﻿/// Tip/Trick: Url Rewriting with ASP.NET
/// by Scott Guthrie
/// http://weblogs.asp.net/scottgu/archive/2007/02/26/tip-trick-url-rewriting-with-asp-net.aspx
///
using System.IO;
using System.Web;
using System.Web.UI;
using System.Web.UI.Adapters;

public class FormRewriterControlAdapter : ControlAdapter
{
    protected override void Render(HtmlTextWriter writer)
    {
        base.Render(new RewriteFormHtmlTextWriter(writer));
    }
}

public class RewriteFormHtmlTextWriter : HtmlTextWriter
{
    public RewriteFormHtmlTextWriter(HtmlTextWriter writer)
        : base(writer)
    {
        this.InnerWriter = writer;
    }

    public RewriteFormHtmlTextWriter(TextWriter writer)
        : base(writer)
    {
        this.InnerWriter = writer;
    }

    public override void WriteAttribute(string name, string value, bool fEncode)
    {
        if (name == "action")
        {
            HttpContext context = HttpContext.Current;
            if (context.Items["ActionAlreadyWritten"] == null)
            {
                value = context.Request.RawUrl;
                context.Items["ActionAlreadyWritten"] = true;
            }
        }
        base.WriteAttribute(name, value, fEncode);
    }
}
